@@ -4,6 +4,8 @@ A class containing all the TI-System commands
 from ti_python_module.err import withConsole as err
 from ti_python_module.err import onlyCheck as cerr
 from ti_python_module.file_handler import create_log as log
+import random as rng
+import time
 
 ###########################################################################################
 
@@ -15,7 +17,7 @@ def recall_value(name:str):
         name (str): The name of the variable from which to recall the value.
     
     Returns:
-        list: a list containing the following data: [name]
+        None: Due to being unable to cache value
     """
     if cerr.type_error(str, name) == False: log("Argument 'name' has to be type string", "ERROR", "TI System", "Recall Value")
 
@@ -23,7 +25,7 @@ def recall_value(name:str):
     
     log("Fetchint the value stored in the system variable with the name '" + name + "'", "INFO", "TI System", "Recall Value")
     print("Fetching value of system variable '" + name + "'")
-    return [name]
+    return None
 
 ###########################################################################################
 
@@ -36,13 +38,13 @@ def store_value(name:str, value):
         value (any): The value to store.
     
     Returns:
-        list: a list containing the following data: [name, value]
+        None: Due to being unable to cache value
     """
     if cerr.type_error(str, name) == False: log("Argument 'name' has to be type string", "ERROR", "TI System", "Store Value")
     err.type_error(str, "str", name)
     log("Storing data '" + str(value) + "' to variable '" + name + "'", "INFO", "TI System", "Store Value")
     print("Storing data '" + str(value) + "' to variable '" + name + "'")
-    return [name, value]
+    return None
 ###########################################################################################
 
 def recall_list(name:str):
@@ -53,7 +55,7 @@ def recall_list(name:str):
         name (str): The name of the list from which to recall the value.
     
     Returns:
-        list: a list containing the following data: [name]
+        None: Due to being unable to cache list
     """
 
     if cerr.type_error(str, name) == False: log("Argument 'name' has to be type string", "ERROR", "TI System", "Recall List")
@@ -61,7 +63,7 @@ def recall_list(name:str):
     err.type_error(str, "str", name)
     log("Recalling values of system list '" + name + "'", "INFO", "TI System", "Recall List")
     print("Fetching value of system list '" + name + "'")
-    return [name]
+    return None
 
 ###########################################################################################
 
@@ -74,7 +76,7 @@ def store_list(name:str, list:list):
         list (list): The values to store int the list.
     
     Returns:
-        list: a list containing the following data: [name, list]
+        None: Due to being unable to cache list
     """
 
     if cerr.type_error(str, name) == False: log("Argument 'name' has to be type string", "ERROR", "TI System", "Store List")
@@ -83,7 +85,7 @@ def store_list(name:str, list:list):
     
     log("Storing the data from the given list to system list '" + name + "'", "INFO", "TI System", "Store List")
     print("Storing data '" + str(list) + "' to variable '" + name + "'")
-    return [name, list]
+    return None
 
 ###########################################################################################
 
@@ -96,7 +98,7 @@ def eval_function(name:str, value):
         value (any): The value to use for the function
     
     Returns:
-        list: a list containing the following data: [name, value]
+        None: Due to being unable to see predefined OS functions
     """
 
     if cerr.type_error(str, name) == False: log("Argument 'name' has to be type string", "ERROR", "TI System", "Evaluate Function")
@@ -104,7 +106,7 @@ def eval_function(name:str, value):
     err.type_error(str, "str", name)
     log("Evaluating the result of using the function '" + name +"' with the value '" + str(value) + "'", "INFO", "TI System", "Evaluate Function")
     print("Evaluating result of '" + name + "' for value '" + str(value) + "'")
-    return [name, value]
+    return None
 
 ###########################################################################################
 
@@ -113,11 +115,11 @@ def get_platform():
     Returns 'hh' for handeld and 'dt' for desktop
     
     Returns
-        None: None
+        str: The platform type shortcut
     """
     log("Fetching current platform type", "INFO", "TI System", "Get Platform")
     print("Fetching platform type")
-    return None
+    return rng.choice(['hh', 'dt'])
 
 ###########################################################################################
 
@@ -129,11 +131,11 @@ def get_key(parameter = None):
         parameter (any, optional): Optional Parameter. If given, waits until key is pressed. Defaults to None.
 
     Returns:
-        list: a list containing the following data: [parameter]
+        str: The pressed key
     """
     log("Fetching Key-String fot '" + str(parameter) + "'", "INFO", "TI System", "Get Key")
     print("Fetching Key-String for '" + str(parameter) + "'")
-    return [parameter]
+    return input("Requesting Key input:  ")
 
 ###########################################################################################
 
@@ -142,7 +144,7 @@ def get_mouse():
     Returns mouse coordinates as a two element tuple, either the canvas pixel position or (-1,-1) if outside the canvas.
     
     Returns
-        None: None
+        None: Due to being unable to fetch mouse position
     """
     log("Fetching the position of the mouse cursor", "INFO", "TI System", "Get Mouse")
     print("Fetching position of mouse cursor")
@@ -168,8 +170,8 @@ def get_time_ms():
     Returns time in milliseconds with millisecond precision. This functionality can be used to calculate a duration rather than determine the actual clock time.
     
     Returns
-        None: None
+        float: The time in milliseconds
     """
     log("Fetching the time in milliseconds", "INFO", "TI System", "Get Time Milliseconds")
     print("Fetching time in milliseconds")
-    return None
\ No newline at end of file
+    return time.time()
\ No newline at end of file
